diff --git a/frontend/components/organisation/tabs/OrganisationTabItems.tsx b/frontend/components/organisation/tabs/OrganisationTabItems.tsx
index 79ed70e..e671c93 100644
--- a/frontend/components/organisation/tabs/OrganisationTabItems.tsx
+++ b/frontend/components/organisation/tabs/OrganisationTabItems.tsx
@@ -36,12 +36,13 @@ export type OrganisationTabProps = {
* NOTE! When changing the tab options also update
* TabContent.tsx file to load proper component.
*/
-export const organistionTabItems:OrganisationTabProps = {
+export const organisationTabItems:OrganisationTabProps = {
+ // disable software option, 2024-07-02
software: {
id:'software',
label:({software_cnt})=>`Software (${software_cnt ?? 0})`,
icon:
,
- isVisible: (props) => true,
+ isVisible: (props) => false,
},
projects:{
id:'projects',
@@ -49,11 +50,12 @@ export const organistionTabItems:OrganisationTabProps = {
icon:
,
isVisible: (props) => true,
},
+ // disable releases option, 2024-07-02
releases: {
id:'releases',
label:({release_cnt})=>`Releases (${release_cnt ?? 0})`,
icon:
,
- isVisible: (props) => true,
+ isVisible: (props) => false,
},
units:{
id:'units',
diff --git a/frontend/components/organisation/tabs/OrganisationTabs.tsx b/frontend/components/organisation/tabs/OrganisationTabs.tsx
index 07cd2fe..8fe8b2f 100644
--- a/frontend/components/organisation/tabs/OrganisationTabs.tsx
+++ b/frontend/components/organisation/tabs/OrganisationTabs.tsx
@@ -7,12 +7,12 @@ import Tab from '@mui/material/Tab'
import Tabs from '@mui/material/Tabs'
import {useRouter} from 'next/router'
-import {TabKey, organistionTabItems} from './OrganisationTabItems'
+import {TabKey, organisationTabItems} from './OrganisationTabItems'
import useOrganisationContext from '../context/useOrganisationContext'
import useSelectedTab from './useSelectedTab'
// extract tab items (object keys)
-const tabItems = Object.keys(organistionTabItems) as TabKey[]
+const tabItems = Object.keys(organisationTabItems) as TabKey[]
export default function OrganisationTabs({tab_id}:{tab_id:TabKey|null}) {
const router = useRouter()
@@ -48,7 +48,7 @@ export default function OrganisationTabs({tab_id}:{tab_id:TabKey|null}) {
aria-label="organisation tabs"
>
{tabItems.map(key => {
- const item = organistionTabItems[key]
+ const item = organisationTabItems[key]
if (item.isVisible({
isMaintainer,
software_cnt,
diff --git a/frontend/components/organisation/tabs/TabContent.tsx b/frontend/components/organisation/tabs/TabContent.tsx
index bd61d3b..69f5601 100644
--- a/frontend/components/organisation/tabs/TabContent.tsx
+++ b/frontend/components/organisation/tabs/TabContent.tsx
@@ -39,18 +39,23 @@ export default function TabContent({tab_id}: TabContentProps) {
switch (select_tab) {
case 'about':
return
+ // IGNORE software and use projects
+ // disable software option, 2024-07-02
+ case 'software':
case 'projects':
return
case 'releases':
return
case 'settings':
return
- case 'software':
- return
+ // disable software option, 2024-07-02
+ // case 'software':
+ // return
case 'units':
return
default:
logger(`Unknown tab_id ${tab_id}...returning default software tab`,'warn')
- return
+ // projects as default option, 2024-07-02
+ return
}
}
diff --git a/frontend/components/projects/edit/editProjectPages.tsx b/frontend/components/projects/edit/editProjectPages.tsx
index b470513..98d875d 100644
--- a/frontend/components/projects/edit/editProjectPages.tsx
+++ b/frontend/components/projects/edit/editProjectPages.tsx
@@ -12,7 +12,7 @@ import FeedIcon from '@mui/icons-material/Feed'
import TeamsIcon from '@mui/icons-material/Groups'
import BusinessIcon from '@mui/icons-material/Business'
import PersonAddIcon from '@mui/icons-material/PersonAdd'
-import TerminalIcon from '@mui/icons-material/Terminal'
+// import TerminalIcon from '@mui/icons-material/Terminal'
import ContentLoader from '~/components/layout/ContentLoader'
import JoinInnerIcon from '@mui/icons-material/JoinInner'
import AddCommentIcon from '@mui/icons-material/AddComment'
@@ -33,9 +33,10 @@ const ProjectMentions = dynamic(() => import('./mentions'),{
const RelatedProjects = dynamic(() => import('./related-projects'),{
loading: ()=>
})
-const RelatedSoftware = dynamic(() => import('./related-software'),{
- loading: ()=>
-})
+// disable software option, 2024-07-02
+// const RelatedSoftware = dynamic(() => import('./related-software'),{
+// loading: ()=>
+// })
const ProjectMaintainers = dynamic(() => import('./maintainers'),{
loading: ()=>
})
@@ -84,13 +85,14 @@ export const editProjectPage: EditProjectPageProps[] = [
render: () =>
,
status: ''
},
- {
- id: 'related-software',
- label: 'Related software',
- icon:
,
- render: () =>
,
- status: ''
- },
+ // disable software option, 2024-07-02
+ // {
+ // id: 'related-software',
+ // label: 'Related software',
+ // icon:
,
+ // render: () =>
,
+ // status: ''
+ // },
{
id: 'maintainers',
label: 'Maintainers',
diff --git a/frontend/components/user/UserNavItems.tsx b/frontend/components/user/UserNavItems.tsx
index fe55298..e1e1fc3 100644
--- a/frontend/components/user/UserNavItems.tsx
+++ b/frontend/components/user/UserNavItems.tsx
@@ -56,41 +56,44 @@ export type UserMenuProps = {
showSearch: boolean
}
-export const userMenu:UserMenuProps[] = [{
- id:'software',
- label:({software_cnt})=>`Software (${software_cnt ?? 0})`,
- icon:
,
- status: 'Software you maintain',
- showSearch: true
-},{
- id:'projects',
- label: ({project_cnt})=>`Projects (${project_cnt ?? 0})`,
- icon:
,
- status: 'Projects you maintain',
- showSearch: true
-},{
- id:'organisations',
- label: ({organisation_cnt})=>`Organisations (${organisation_cnt ?? 0})`,
- icon:
,
- status: 'Organisations you maintain',
- showSearch: true
-},{
- id:'communities',
- label: ({community_cnt})=>`Communities (${community_cnt ?? 0})`,
- icon:
,
- status: 'Communities you maintain',
- showSearch: true
-},{
- id:'project-quality',
- label: () => 'Project metadata overview',
- icon:
,
- status: 'Overview of the completeness of project pages you maintain',
- showSearch: false
-},{
- id:'settings',
- label: () => 'Settings',
- icon:
,
- status: 'Your profile settings',
- showSearch: false
-},
+export const userMenu:UserMenuProps[] = [
+// disable software option, 2024-07-02
+// {
+// id:'software',
+// label:({software_cnt})=>`Software (${software_cnt ?? 0})`,
+// icon:
,
+// status: 'Software you maintain',
+// showSearch: true
+// },
+ {
+ id:'projects',
+ label: ({project_cnt})=>`Projects (${project_cnt ?? 0})`,
+ icon:
,
+ status: 'Projects you maintain',
+ showSearch: true
+ },{
+ id:'organisations',
+ label: ({organisation_cnt})=>`Organisations (${organisation_cnt ?? 0})`,
+ icon:
,
+ status: 'Organisations you maintain',
+ showSearch: true
+ },{
+ id:'communities',
+ label: ({community_cnt})=>`Communities (${community_cnt ?? 0})`,
+ icon:
,
+ status: 'Communities you maintain',
+ showSearch: true
+ },{
+ id:'project-quality',
+ label: () => 'Project metadata overview',
+ icon:
,
+ status: 'Overview of the completeness of project pages you maintain',
+ showSearch: false
+ },{
+ id:'settings',
+ label: () => 'Settings',
+ icon:
,
+ status: 'Your profile settings',
+ showSearch: false
+ },
]
diff --git a/frontend/pages/organisations/index.tsx b/frontend/pages/organisations/index.tsx
index e00a070..2c40f9e 100644
--- a/frontend/pages/organisations/index.tsx
+++ b/frontend/pages/organisations/index.tsx
@@ -14,7 +14,6 @@ import Pagination from '@mui/material/Pagination'
import PaginationItem from '@mui/material/PaginationItem'
import {app} from '~/config/app'
-import {useUserSettings} from '~/config/UserSettingsContext'
import PageTitle from '~/components/layout/PageTitle'
import Searchbox from '~/components/form/Searchbox'
import {OrganisationList} from '~/types/Organisation'
@@ -24,7 +23,7 @@ import {getOrganisationsList} from '~/components/organisation/apiOrganisations'
import PageMeta from '~/components/seo/PageMeta'
import AppFooter from '~/components/AppFooter'
import AppHeader from '~/components/AppHeader'
-import {getUserSettings, setDocumentCookie} from '~/utils/userSettings'
+import {getUserSettings} from '~/utils/userSettings'
import useSearchParams from '~/components/search/useSearchParams'
import OrganisationGrid from '~/components/organisation/overview/OrganisationGrid'
import PageBackground from '~/components/layout/PageBackground'
diff --git a/frontend/pages/projects/[slug]/index.tsx b/frontend/pages/projects/[slug]/index.tsx
index d4cdef4..39c3af3 100644
--- a/frontend/pages/projects/[slug]/index.tsx
+++ b/frontend/pages/projects/[slug]/index.tsx
@@ -54,6 +54,7 @@ export interface ProjectPageProps extends ScriptProps{
output: MentionItemProps[],
impact: MentionItemProps[],
team: Person[],
+ // disable software option, 2024-07-02
relatedSoftware: SoftwareOverviewItemProps[],
relatedProjects: RelatedProject[]
}
@@ -169,7 +170,8 @@ export async function getServerSideProps(context:any) {
output,
impact,
team,
- relatedSoftware,
+ // disable software option, 2024-07-02
+ // relatedSoftware,
relatedProjects,
links,
isMaintainer
@@ -182,7 +184,8 @@ export async function getServerSideProps(context:any) {
// Impact
getImpactByProject({project: project.id, token}),
getTeamForProject({project: project.id, token}),
- getRelatedSoftwareForProject({project: project.id, token, frontend: false}),
+ // disable software option, 2024-07-02
+ // getRelatedSoftwareForProject({project: project.id, token, frontend: false}),
getRelatedProjectsForProject({project: project.id, token, frontend: false}),
getLinksForProject({project: project.id, token, frontend: false}),
isMaintainerOfProject({slug, account:userInfo?.account, token, frontend: false}),
@@ -202,7 +205,8 @@ export async function getServerSideProps(context:any) {
output,
impact,
team,
- relatedSoftware,
+ // disable software option, 2024-07-02
+ relatedSoftware:[],
relatedProjects,
links
},
diff --git a/frontend/public/data/settings.json b/frontend/public/data/settings.json
index 61d2d0a..947446f 100644
--- a/frontend/public/data/settings.json
+++ b/frontend/public/data/settings.json
@@ -1,7 +1,6 @@
{
"host": {
"name": "kin-rpd",
- "email": "rsd@esciencecenter.nl",
"emailHeaders": [],
"logo_url": "/images/logo-KIN.svg",
"website": "https://hetkin.nl",
@@ -48,7 +47,7 @@
"colors": {
"base-100": "#fff",
"base-200": "#eeeeee",
- "base-300": "#e1eee5",
+ "base-300": "#e5e3e3",
"base-400": "#bdbdbd",
"base-500": "#9e9e9e",
"base-600": "#3f7f94",
@@ -56,14 +55,14 @@
"base-800": "#386f82",
"base-900": "#306070",
"base-content": "#306070",
- "base-content-secondary": "rgba(34,36,37,0.7)",
+ "base-content-secondary": "rgba(48,96,112,0.7)",
"base-content-disabled": "rgba(34,36,37,0.45)",
"primary": "#01A2D6",
"primary-content": "#fff",
"secondary": "#306070",
"secondary-content": "#fff",
- "accent": "#71AD93",
- "accent-content": "#fff",
+ "accent": "#a3ccb9",
+ "accent-content": "#306070",
"error": "#8A1D12",
"error-content": "#fff",
"warning": "#ed6c02",
@@ -93,7 +92,7 @@
"colors": {
"base-100": "#306070",
"base-200": "#56956a",
- "base-300": "#4d855e",
+ "base-300": "#e1eee5",
"base-400": "#757575",
"base-500": "#9e9e9e",
"base-600": "#bdbdbd",
diff --git a/frontend/components/organisation/tabs/useSelectedTab.tsx b/frontend/components/organisation/tabs/useSelectedTab.tsx
index f395b08..d32b502 100644
--- a/frontend/components/organisation/tabs/useSelectedTab.tsx
+++ b/frontend/components/organisation/tabs/useSelectedTab.tsx
@@ -3,22 +3,22 @@
//
// SPDX-License-Identifier: Apache-2.0
-import {TabKey, organistionTabItems} from './OrganisationTabItems'
+import {TabKey, organisationTabItems} from './OrganisationTabItems'
import useOrganisationContext from '../context/useOrganisationContext'
// extract tab items (object keys)
-// const tabItems = Object.keys(organistionTabItems) as TabKey[]
+// const tabItems = Object.keys(organisationTabItems) as TabKey[]
export default function useSelectedTab(tab_id: TabKey|null) {
const {description, isMaintainer} = useOrganisationContext()
- // default tab is software
- let selected:TabKey = 'software'
+ // default tab is projects
+ let selected:TabKey = 'projects'
// if tab provided use it
- if (tab_id !== null && organistionTabItems.hasOwnProperty(tab_id) === true) {
+ if (tab_id !== null && organisationTabItems.hasOwnProperty(tab_id) === true) {
selected = tab_id
- } else if (organistionTabItems['about'].isVisible({description,isMaintainer})===true) {
+ } else if (organisationTabItems['about'].isVisible({description,isMaintainer})===true) {
// if tab is not provided and there is description
// the default tab is about
selected = 'about'